@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.09026';
+our $VERSION = '0.15026';
 
 $VERSION =~ /([0-9]{2})$/;
 my $compat_version = $1;
@@ -83,6 +83,16 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
 
+} elsif($^O eq 'msys') {
+
+    # MSYS2 seems to actually set PKG_CONFIG_PATH in its /etc/profile
+    # god bless it.  But.  The defaults if you unset the environment
+    # variable are different
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/lib/pkgconfig
+        /usr/share/pkgconfig
+    );
+
 } elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
 
     @DEFAULT_SEARCH_PATH = qw(
@@ -413,7 +423,7 @@ struct(
      # will be listed first
      'libs_deplist' => '*%',
 
-     # cummulative cflags and ldflags
+     # cumulative cflags and ldflags
      'ldflags'   => '*@',
      'cflags'    => '*@',
 
@@ -707,7 +717,7 @@ sub parse_line {
     #perl variables can't have '.' in them:
     $field =~ s/\./DOT/g;
     
-    #remove quoutes from field names
+    #remove quotes from field names
     $field =~ s/['"]//g;
     
 
@@ -726,7 +736,7 @@ sub parse_line {
     $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
       if $value =~ /[\\"']/;
     
-    #quoute the value string, unless quouted already
+    #quote the value string, unless quoted already
     $value = "\"$value\"";
     
     #get existent variables from our hash:
@@ -767,6 +777,9 @@ sub parse_pcfile {
     
 
     $self->append_cflags(  $self->_pc_var('cflags') );
+    if($self->static) {
+        $self->append_cflags( $self->_pc_var('cflags.private') );
+    }
     $self->append_ldflags( $self->_pc_var('libs') );
     if($self->static) {
         $self->append_ldflags( $self->_pc_var('libs.private') );
@@ -1070,6 +1083,7 @@ GetOptions(
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
     'errors-to-stdout' => \my $ErrToStdOut,
+    'short-errors'     => \my $ShortErrors,
     
     'define-variable=s', => \my %UserVariables,
     
@@ -1089,6 +1103,9 @@ GetOptions(
     'h|help|?'      => \my $WantHelp
 ) or pod2usage(@POD_USAGE_OPTIONS);
 
+if($^O eq 'msys' && !$ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+    $UseStatic = 1;
+}
 
 if($WantHelp) {
     pod2usage(@POD_USAGE_OPTIONS, -exitval => 0);
@@ -1277,7 +1294,7 @@ PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
     $ ppkg-config --libs --cflags --static gio-2.0
 
-    #outputs (lines artifically broken up for readability):
+    #outputs (lines artificially broken up for readability):
     # -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include
     # -pthread -lgio-2.0 -lz -lresolv -lgobject-2.0
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
@@ -1434,6 +1451,10 @@ arguments
 Print errors to STDERR and takes precedence over
 C<--silence-errors>
 
+=head4 --short-errors
+
+Ignored, but recognized for compatibility.
+
 =head4 --errors-to-stdout
 
 Print errors to STDOUT and takes precedence over
@@ -1477,7 +1498,7 @@ a working version that implements this feature.
 
 =head4 I<< PkgConfig->find >>
 
-    my $result = PkgConfig->find($libary, %options);
+    my $result = PkgConfig->find($library, %options);
 
 Find a library and return a result object.
 C<$library> can be either a single name of a library, or a reference to an
@@ -1659,6 +1680,14 @@ package itself (without dependencies).
 
 The original C implementation
 
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=item L<PkgConfig::LibPkgConf>
+
+Perl bindings for C<libpkgconf>, the same library that C<pkgconf> is built on.
+
 =item L<ExtUtils::PkgConfig>
 
 A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
@@ -1668,10 +1697,6 @@ or C<Build.PL>.
 
 Another perl implementation of pkg-config
 
-=item L<pkgconf|https://github.com/pkgconf/pkgconf>
-
-An alternative C implementation
-
 =item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
 
 Pure Ruby implementation.
@@ -1704,6 +1729,8 @@ Other contributors include:
 
 =item Breno G. de Oliveira (garu)
 
+=item Gregor Herrmann
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
